/*  Freckles problem
	 Coded by Angel Paredes
	 Algorithm: Minimum Spanning Tree (Kruskal)
*/
#include <iostream>
#include <algorithm>
#include <vector>
#include <cmath>
#include <cstdio>

using namespace std;

const int MAXN = 100;

double x[MAXN];
double y[MAXN];

int rank[MAXN];
int parent[MAXN];

struct Edge
{
	double cost;
	int u, v;
	Edge(){}
	Edge(int u, int v, double cost):u(u), v(v), cost(cost){}

    friend bool operator < (const Edge &e1, const Edge &e2)
    {
         return e1.cost < e2.cost;
    }
};

double dist(double x1, double y1, double x2, double y2)
{
	return sqrt((x1-x2)*(x1-x2) + (y1-y2)*(y1-y2));
}

// implemets Find heuristic
int Find(int x)
{
	if (parent[x] != x)
		parent[x] = Find(parent[x]);
	return parent[x];
}

// implements Union heuristic
bool Union(int a, int b)
{
	int pa = Find(a); 
	int pb = Find(b);

	if (pa == pb) return false;

	if (rank[pa] < rank[pb])
		parent[pa] = pb;
	else
	{
		parent[pb] = pa;
		if (rank[pa] == rank[pb])
			rank[pa]++;
	}
	return true;
}

double Kruskal(int n, vector<Edge> &edges)
{
	// initialize Disjoint-set data-structures
	for (int i = 0; i < n; i++)
	{
		parent[i] = i;
		rank[i] = 1;
	}

	sort(edges.begin(), edges.end());

	int e = 0; // number of edges that have been added to the MST
	double mst_cost = 0;

	for (int i = 0; i < edges.size() && e < n - 1; i++)
	{
		int u = edges[i].u;
		int v = edges[i].v;
		double cost = edges[i].cost;

		if (Union(u,v))
		{
			mst_cost += cost;
			e++;
		}
	}

	return mst_cost;
}

int main()
{
	int t;
	cin >> t; // # of test cases
	while (t--)
	{
		int n;  // # of freckles (points)
		cin >> n;
		for (int i = 0; i < n; i++)
			cin >> x[i] >> y[i];

		vector<Edge> edges; 
		// create the edges
		for (int i = 0; i < n - 1; i++)
			for (int j = i + 1; j < n; j++)
				edges.push_back( Edge( i, j, dist( x[i], y[i], x[j], y[j] ) ) );

		double sol = Kruskal(n, edges);

		printf("%.2lf\n", sol);

		if (t > 0)
			printf("\n");
	}
	return 0;
}
