// The Tourist Guide

// Judge's solution

import java.util.PriorityQueue;
import java.util.List;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Scanner;

class Vertex implements Comparable<Vertex>
{
    public final String name;
    public ArrayList<Edge> adjacencies;
    public double maxNumTourists = 0;
    public Vertex previous;
    
    public Vertex(String argName) { 
    	name = argName; 
    	adjacencies = new ArrayList<Edge>();
    }
    
    public String toString() 
    { return name; }
    
    
    public int compareTo(Vertex other)
    {
        return Integer.compare((int)maxNumTourists, (int)other.maxNumTourists);
    }
    
}
class Edge
{
    public final Vertex target;
    public final double weight;
    
    public Edge(Vertex argTarget, double argWeight)
    { 
    	target = argTarget; 
    	weight = argWeight; 
    }
}

public class Main
{
    public static void computePaths(Vertex source)
    {
        PriorityQueue<Vertex> vertexQueue = new PriorityQueue<Vertex>();
        vertexQueue.add(source);

        while (!vertexQueue.isEmpty()) {
        	Vertex u = vertexQueue.poll();   
			
            for (Edge e : u.adjacencies)
            {
                Vertex v = e.target;
                double weight = e.weight;
                double distanceThroughU = -1;
                
                if(u.maxNumTourists > weight){
                	distanceThroughU = weight; //send the "weight"
                } else{
                	distanceThroughU = u.maxNumTourists; //send all tourists
                }
                
                if (distanceThroughU > v.maxNumTourists) {
                	vertexQueue.remove(v);
                	v.maxNumTourists = distanceThroughU ;
                	v.previous = u;
                	vertexQueue.add(v);
                }  // if
            }   // for each edge in u's adjacency list
            
        }  // while queue is not empty
    }  // computePaths


    public static List<Vertex> getShortestPathTo(Vertex target)
    {
        List<Vertex> path = new ArrayList<Vertex>();
        for (Vertex vertex = target; vertex != null; vertex = vertex.previous)
            path.add(vertex);

        Collections.reverse(path);
        return path;
    }

    public static void main(String[] args)
    {	
    	Scanner sc = new Scanner(System.in);
    	int scenario = 0;
        
    	while(sc.hasNext()){
    		scenario++;
	    	int numVertices = sc.nextInt();
	    	int numEdges = sc.nextInt();
	    	
	    	if(numVertices == 0 && numEdges == 0){
	    		break;
	    	}
	    	
	    	Vertex [] vertices = new Vertex[numVertices];
	    	
	    	for(int i = 0; i < numVertices; i++){ //create vertex objects
	    		Vertex v = new Vertex(String.valueOf(i+1));
	    		vertices[i] = v;
	    	}
	    	
	    	for(int i = 1; i <= numEdges; i++){ //add edges to correspondent vertices
	    		int a = sc.nextInt();
	    		int b = sc.nextInt();
	    		double weight = sc.nextDouble();
	    		weight = weight - 1;
	    		
	    		Vertex source = vertices[a-1];
	    		Vertex target = vertices[b-1];
	    		Edge e1 = new Edge(target, weight);
	    		source.adjacencies.add(e1);
	    		
	    		Vertex newSource = vertices[b-1];
	    		Vertex newTarget = vertices[a-1];
	    		Edge e2 = new Edge(newTarget, weight);
	    		newSource.adjacencies.add(e2);
	    	}
	
	    	int sourceVertex = sc.nextInt();
	    	int targetVertex = sc.nextInt();
	    	int numPassangers = sc.nextInt();
	    	int bestRoute = 0;
	    	
	    	vertices[sourceVertex-1].maxNumTourists = numPassangers;
	        computePaths(vertices[sourceVertex-1]); //Call to Dijkstra's traversal
	        
        	bestRoute = (int)vertices[targetVertex-1].maxNumTourists; //record max num tourists per trip 
	        System.out.println("Scenario #" + scenario);
	        
	        int answer = numPassangers/bestRoute;
	        
	        if(numPassangers%bestRoute == 0){
	        	System.out.println("Minimum Number of Trips = " + (answer));
	        } else{
	        	System.out.println("Minimum Number of Trips = " + (answer + 1));
	        }
	        
	        System.out.println();
	    }
    }
}

